/*****************************************************************************
 * BF707_MDMA_Throughput_measure.c
 *****************************************************************************/
/*This code can be used to perform read and write throughput measurements for MDMA
 * under various conditions: sequential, non-sequential, different MSIZE values,
 * different DDR/L2 settings etc.
 */
#include "adi_initialize.h"
#include "MDMA_Throughput_measure.h"
volatile clock_t clock_start;
volatile clock_t clock_stop;
volatile clock_t cycles;
volatile clock_t overhead;
volatile clock_t actual_cycles;

float throughput;

#pragma align 32
section("L1_data_a") unsigned char ucIntSrcBuff[1];
//section("L2_sram") unsigned char ucIntSrcBuff[1];

#pragma align 32
section("L1_data_b") unsigned char ucIntDestBuff[MAX_SIZE];
//section("l2_sram") unsigned char ucIntDestBuff[MAX_SIZE1];

#pragma align 32
//section("L2_scratchpad") unsigned char ucExtSrcBuff[MAX_SIZE1];
section("sdram0_bank0") unsigned char ucExtSrcBuff[MAX_SIZE];
//section("l2_sram") unsigned char ucExtSrcBuff[MAX_SIZE];
//section("L1_data_a") unsigned char ucExtSrcBuff[MAX_SIZE];

#pragma align 32
section("sdram0_bank0") unsigned char ucExtDestBuff[MAX_SIZE];
//section("L2_scratchpad") unsigned char ucExtDestBuff[MAX_SIZE1];


void Measure_Throughput_Read_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig);
void Measure_Throughput_Write_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig);
void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount);

#define MDMA_CONFIG(S_MDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT,D_MDMA_CHANNEL,D_CFG, D_ADDRSTART, D_MOD, D_COUNT)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##S_MDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##S_MDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##S_MDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = D_CFG;\
		*pREG_DMA##D_MDMA_CHANNEL##_ADDRSTART = D_ADDRSTART;\
		*pREG_DMA##D_MDMA_CHANNEL##_XCNT = D_COUNT;\
		*pREG_DMA##D_MDMA_CHANNEL##_XMOD = D_MOD;\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG |= 0x1;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG |= 0x1;\

#define WAIT_FOR_DMADONE(DMA_CHANNEL)\
		while(!(*pREG_DMA##DMA_CHANNEL##_STAT & ENUM_DMA_STAT_IRQDONE));

#define DISABLE_DMAs(S_MDMA_CHANNEL, D_MDMA_CHANNEL)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = 0;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = 0;

int main(void)
{
	//Enable MDMA1/2 streams as secure master
	*pREG_SPU0_SECUREP53=0x3;
	*pREG_SPU0_SECUREP54=0x3;
	*pREG_SPU0_SECUREP55=0x3;
	*pREG_SPU0_SECUREP56=0x3;

	//Program clock domain crossing registers in SYNC mode
	*pREG_SCB0_MST30_SYNC=0;
	*pREG_SCB0_MST31_SYNC=0;
	*pREG_SCB0_IB7_SYNC=0;

	//Uncomment this line to disable ECC for L2
	//*pREG_L2CTL0_CTL=0xFF;

	//Change the DMC efficiency controller settings here
	//*pREG_DMC0_CTL|=BITM_DMC_CTL_ADDRMODE|BITM_DMC_CTL_PREC; //|BITM_DMC_CTL_PPREF
	*pREG_DMC0_CTL|=BITM_DMC_CTL_PPREF;
	*pREG_DMC0_EFFCTL|=(0xF<<BITP_DMC_EFFCTL_NUMREF)|(0xF<<BITP_DMC_EFFCTL_IDLECYC);

	//*pREG_DMC0_EMR1|=(0x2<<BITP_DMC_EMR1_AL);
	//*pREG_DMC0_CTL|=BITM_DMC_CTL_ADDRMODE;

	adi_initComponents();
	unsigned int uiBytes=0;

	//Measure Read/Write throughput for different number of bytes (32, 64, 128...16384)
		for(uiBytes=32;uiBytes<=MAX_SIZE;uiBytes=uiBytes*2)
		{
			Fill_Buff(ucExtSrcBuff, uiBytes);
			Measure_Throughput_Read_MDMA(uiBytes, SOURCE_DMA_CFG, DEST_DMA_CFG);
		//	Measure_Throughput_Write_MDMA(uiBytes, SOURCE_DMA_CFG, DEST_DMA_CFG);
		}


	return 0;
}


void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount)
{
	int i=0;

	for(i=0;i<uiCount;i++)
		*ucpBuff++=i;

}
void Measure_Throughput_Read_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig)
{


	*pREG_DMA18_BWMCNT=0x7FFFFFFF;
	//*pREG_DMA20_BWMCNT=0x7FFFFFFF;

	//Configure MDMA to read from external memory
	MDMA_CONFIG(18, uiSourceDMAConfig, ucExtSrcBuff, SOURCE_MSIZE, uiBytes/SOURCE_MSIZE,19,uiDestDMAConfig, ucIntDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);
//	MDMA_CONFIG(20, uiSourceDMAConfig, ucExtSrcBuff, SOURCE_MSIZE, uiBytes/SOURCE_MSIZE,21,uiDestDMAConfig, ucIntDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);


	//Start cycle counter
	clock_start = 0x7FFFFFFF;

	//Wait for the DMA done
	WAIT_FOR_DMADONE(19);
	//WAIT_FOR_DMADONE(21);

	clock_stop = *pREG_DMA18_BWMCNT_CUR;
//	clock_stop = *pREG_DMA20_BWMCNT_CUR;

	//Calculate no of CCLK cycles
	cycles=clock_start-clock_stop;

	//Disable the DMAs
	DISABLE_DMAs(18,19);
//	DISABLE_DMAs(20,21);

	//Calculate the throughput and print the same
	throughput=(float)(uiBytes*SCLK_SPEED/cycles);
	printf("\n\n No of bytes=%d, No of cycles=%d, ",uiBytes,cycles,throughput);
	printf("Throughput=%f MB/s\n\n",throughput);

}

void Measure_Throughput_Write_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig)
{

	//*pREG_DMA18_BWMCNT=0x7FFFFFFF;
	*pREG_DMA20_BWMCNT=0x7FFFFFFF;

	//Configure MDMA to write to external memory
//	MDMA_CONFIG(18, uiSourceDMAConfig, ucIntSrcBuff, SOURCE_MSIZE, uiBytes/SOURCE_MSIZE,19,uiDestDMAConfig, ucExtDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);
	MDMA_CONFIG(20, uiSourceDMAConfig, ucIntSrcBuff, SOURCE_MSIZE, uiBytes/SOURCE_MSIZE,21,uiDestDMAConfig, ucExtDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);

	//Start cycle count
	clock_start = 0x7FFFFFFF;

	//Wait for the DMA done
	WAIT_FOR_DMADONE(21);

	//Stop cycle count
	clock_stop = *pREG_DMA20_BWMCNT_CUR;

	//Calculate no of cycles
	cycles=clock_start-clock_stop;

	//Disable the DMAs
	DISABLE_DMAs(20,21);

	//Calculate and print throughput values
	throughput=(float)(uiBytes*SCLK_SPEED/cycles);
	printf("\n\n No of bytes=%d, No of cycles=%d, ",uiBytes,cycles,throughput);
	printf("Throughput=%f MB/s\n\n",throughput);

}





