/*****************************************************************************
 * Stress_Test1_Core0.h
 *****************************************************************************/

#ifndef __STRESS_TEST1_CORE0_H__
#define __STRESS_TEST1_CORE0_H__

#include <ccblkfn.h>
#include "adi_initialize.h"
#include <cdefBF707.h>
#include <defBF707.h>
#include "time.h"
#include "stdio.h"


//Macro to configure MDMA
#define MDMA_CONFIG(S_MDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT,D_MDMA_CHANNEL,D_CFG, D_ADDRSTART, D_MOD, D_COUNT)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##S_MDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##S_MDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##S_MDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = D_CFG;\
		*pREG_DMA##D_MDMA_CHANNEL##_ADDRSTART = D_ADDRSTART;\
		*pREG_DMA##D_MDMA_CHANNEL##_XCNT = D_COUNT;\
		*pREG_DMA##D_MDMA_CHANNEL##_XMOD = D_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG|= 0x1;\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG|= 0x1;

//Macro to disable the MDMAs
#define DISABLE_MDMAs(S_MDMA_CHANNEL, D_MDMA_CHANNEL)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = 0;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = 0;

//Macro to disable PPIDMA
#define DISABLE_PPI_DMA(DMA_CHANNEL)\
		*pREG_DMA##DMA_CHANNEL##_CFG = 0;

//Macro to enable peripheral DMA
#define PDMA_CONFIG(PDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT)\
		*pREG_DMA##PDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##PDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##PDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##PDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##PDMA_CHANNEL##_CFG|= 0x1;


#define ENABLE_PPI0_DMA_150_MBPS
#define ENABLE_MDMA1_DMA_800MBPS
#define ENABLE_MDMA2_DMA_800MBPS

#define PAGE_SIZE 2048
#define ROWS_PER_BANK 16384
#define BANK_SIZE PAGE_SIZE*ROWS_PER_BANK

#define SOURCE_MSIZE_MDMA0 32
#define USE_SINGLE_BANK

//T1
//#define USE_MULTIPLE_BANKS


//T2
//#define LIMIT_MDMA1_BW 300
//#define LIMIT_MDMA2_BW 300

//T3
//#define LIMIT_MDMA1_BW 500
//#define LIMIT_MDMA2_BW 100



#ifdef USE_MULTIPLE_BANKS
	#define PPI0_DMA_DMC_START_ADDRESS  0x80000000+0*BANK_SIZE
	#define MDMA1_DMA_DMC_START_ADDRESS 0x80000000+1*BANK_SIZE
	#define MDMA2_DMA_DMC_START_ADDRESS 0x80000000+2*BANK_SIZE
#endif

#ifdef USE_SINGLE_BANK
	#define PPI0_DMA_DMC_START_ADDRESS 	0x80000000
	#define MDMA1_DMA_DMC_START_ADDRESS 0x80000000+4*1*PAGE_SIZE*4
	#define MDMA2_DMA_DMC_START_ADDRESS 0x80000000+4*2*PAGE_SIZE*4
#endif

#define SOURCE_MDMA_CHANNEL 18
#define DEST_MDMA_CHANNEL 19

#define SOURCE_PSIZE_MDMA1 		 4
#define DEST_PSIZE_MDMA1   		 4
#define SOURCE_MSIZE_MDMA1		 32
#define DEST_MSIZE_MDMA1  		 32
#define SOURCE_DMA_CFG_MDMA1 	 ENUM_DMA_CFG_MSIZE32|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_XCNT_INT|ENUM_DMA_CFG_AUTO
#define DEST_DMA_CFG_MDMA1		 BITM_DMA_CFG_WNR|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_MSIZE32|ENUM_DMA_CFG_XCNT_INT|ENUM_DMA_CFG_AUTO

#define SOURCE_PSIZE_MDMA2		 4
#define DEST_PSIZE_MDMA2   		 4
#define SOURCE_MSIZE_MDMA2 		 32
#define DEST_MSIZE_MDMA2   		 32
#define SOURCE_DMA_CFG_MDMA2 	 ENUM_DMA_CFG_MSIZE32|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_XCNT_INT|ENUM_DMA_CFG_AUTO
#define DEST_DMA_CFG_MDMA2 		 BITM_DMA_CFG_WNR|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_MSIZE32|ENUM_DMA_CFG_XCNT_INT|ENUM_DMA_CFG_AUTO

#define PPI0_PSIZE 4
#define PPI0_MSIZE 32
#define PPI0_DMA_CFG ENUM_DMA_CFG_MSIZE32|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_XCNT_INT|ENUM_DMA_CFG_AUTO

#define CCLK_SPEED 400
#define SCLK1_SPEED 200

#define MAX_SIZE 4*PAGE_SIZE

#define EPPI0_CTL_CFG ENUM_EPPI_CTL_TXMODE|ENUM_EPPI_CTL_NON656|ENUM_EPPI_CTL_INTCLK|ENUM_EPPI_CTL_INTFS|ENUM_EPPI_CTL_DLEN24|ENUM_EPPI_CTL_PACK_EN|ENUM_EPPI_CTL_EN
#define EPPI0_CTL2_CFG 0




/*************************************************************************************************************************
									Function Prototypes
**************************************************************************************************************************/
// This function initializes the SEC and installs the interrupt handler for corresponding EPPI
void init_interrupts(unsigned int uiPID);


// This function acts as ISR for  EPPI0 DMA channel completion interrupt
void EPPI0_Interrupt_Handler (uint32_t iid, void* handlerArg);


// This function acts as ISR for  EPPI1 DMA channel completion interrupt
void EPPI1_Interrupt_Handler (uint32_t iid, void* handlerArg);


// This function acts as ISR for  EPPI2 DMA channel completion interrupt
void EPPI2_Interrupt_Handler (uint32_t iid, void* handlerArg);


//This function initializes the value of EPPI Control and Clock_Div registers.
void EPPI_Control_Config(unsigned int uiPID, unsigned int uiEPPI_CTL, unsigned int uiEPPI_CTL2, unsigned int uiEPPI_CLKDIV);

//This function initializes the value of EPPI Frame sync delay registers to generate delayed frame sync.
void EPPI_FSDelay_Config(unsigned int uiPID, unsigned int uiEPPI_FS1_DLY, unsigned int uiEPPI_FS2_DLY);

//This function initializes the value of EPPI Frame sync width and period registers to generate internal frame syncs.
void EPPI_FSync_Config(unsigned int uiPID, unsigned int uiEPPI_FS1_WLHB, unsigned int uiEPPI_FS1_PASPL, unsigned int uiEPPI_FS2_WLVB , unsigned int uiEPPI_FS2_PALPF );

//This function initializes the value of EPPI Line, HCNT and HDelay registers.
void EPPI_Line_Config(unsigned int uiPID, unsigned int uiEPPI_LINE, unsigned int uiEPPI_HCNT, unsigned int uiEPPI_HDLY);

//This function initializes the value of EPPI FRAME, VCNT and VDelay registers.
void EPPI_Frame_Config(unsigned int uiPID, unsigned int uiEPPI_FRAME, unsigned int uiEPPI_VCNT, unsigned int uiEPPI_VDLY);

//This function initializes the value of EPPI IMASK register for enabling the interrupts.
void EPPI_IMASK_Config(unsigned int uiPID, unsigned int uiEPPI_IMSK );

//This function initializes the value of EPPI Even and Odd clipping registers.
void EPPI_Clip_Config(unsigned int uiPID, unsigned int uiEPPI_ODDCLIP, unsigned int uiEPPI_EVENCLIP);

//This function Enables(starts) the EPPI module.
void EPPI_Enable(unsigned int uiPID);

//This function initializes the DMA channel for corresponding EPPI
void EPPI_DMANormal_Config(unsigned int uiPID, int* iBufferAddress, int iXModifier, unsigned int uiXSize, int iYModifier, unsigned int uiYSize, unsigned int uiDMAConfig);

//This function initializes the pin multiplexing to enable signals corresponding to selected EPPI.
void EPPI_Pin_Config(unsigned int uiPID, unsigned int uiFS_MODE, unsigned int uiDATAWIDTH);









/*************************************************************************************************************************
									File Details
**************************************************************************************************************************
	File name 							: EPPIInit.C
	Purpose								: Has functions to initialize EPPI Registers, DMA registers and Pin Muxing
	Author								: Nabeel Shah
	VDSP version used for testing		: Analog Devices CCES
										  Version: 1.3.33.201110141233
                                          Build id: 201110141233
	Hardware used						: N/A
	Connection details 					: N/A
	Guidelines for change				: N/A
**************************************************************************************************************************/

/*************************************************************************************************************************
									Include Files
*************************************************************************************************************************/
//#include "EPPIInit.h"
#include <ccblkfn.h>


/*************************************************************************************************************************
									Function Definitions
**************************************************************************************************************************/

/**************************************************************************************************************************
	Function name	:   EPPI_Control_Config
    Description		:   This function initializes the EPPI_CTL, EPPI_CTL2 and EPPI_CLKDIV registers.

	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |  Peripheral ID (	EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiEPPI_CTL		 	 |  EPPI_CTL register value				    | 32 bit unsigned integer value
						uiEPPI_CTL2			 |  EPPI_CTL2 register value				| 32 bit unsigned integer value
						uiEPPI_CLKDIV		 |  EPPI_CLKDIV register value				| 32 bit unsigned integer value
												Used only when internal clock option
												is used
	Return value	:   None.
**************************************************************************************************************************/
void EPPI_Control_Config(unsigned int uiPID, unsigned int uiEPPI_CTL, unsigned int uiEPPI_CTL2, unsigned int uiEPPI_CLKDIV)
{
	switch(uiPID)
	{
		//EPPI0
		case 0:
			*pREG_EPPI0_CTL			= uiEPPI_CTL;
			*pREG_EPPI0_CTL2 		= uiEPPI_CTL2;
			*pREG_EPPI0_CLKDIV	    = uiEPPI_CLKDIV;
			break;

		//EPPI1
		case 1:
	/*		*pREG_EPPI1_CTL			= uiEPPI_CTL;
			*pREG_EPPI1_CTL2 		= uiEPPI_CTL2;
			*pREG_EPPI1_CLKDIV	    = uiEPPI_CLKDIV;*/
			break;

		//EPPI2
		case 2:
	/*		*pREG_EPPI2_CTL			= uiEPPI_CTL;
			*pREG_EPPI2_CTL2 		= uiEPPI_CTL2;
			*pREG_EPPI2_CLKDIV	    = uiEPPI_CLKDIV;*/
			break;
	}

}


/**************************************************************************************************************************
	Function name	:   EPPI_FSDelay_Config
    Description		:   This function initializes the value of EPPI Frame sync delay registers to generate delayed frame sync.

	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |  Peripheral ID (	EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiEPPI_FS1_DLY		 |  EPPI FS1 delay register value			| 32 bit unsigned integer value
						uiEPPI_FS2_DLY		 |  EPPI FS2 delay register value			| 32 bit unsigned integer value

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_FSDelay_Config(unsigned int uiPID, unsigned int uiEPPI_FS1_DLY, unsigned int uiEPPI_FS2_DLY)
{
		switch(uiPID)
	{
		//EPPI0
		case 0:
			*pREG_EPPI0_FS1_DLY		= uiEPPI_FS1_DLY;
			*pREG_EPPI0_FS2_DLY		= uiEPPI_FS2_DLY;
			break;

		//EPPI1
		case 1:
	/*		*pREG_EPPI1_FS1_DLY		= uiEPPI_FS1_DLY;
			*pREG_EPPI1_FS2_DLY		= uiEPPI_FS2_DLY;*/
			break;

		//EPPI2
		case 2:
/*			*pREG_EPPI2_FS1_DLY		= uiEPPI_FS1_DLY;
			*pREG_EPPI2_FS2_DLY		= uiEPPI_FS2_DLY;*/
			break;
	}

}


/**************************************************************************************************************************
	Function name	:   EPPI_FSync_Config
    Description		:   This function initializes the value of EPPI Frame sync width and period registers to generate internal frame syncs.

	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |  Peripheral ID (	EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiEPPI_FS1_WLHB		 |  EPPI FS1 Width							| 32 bit unsigned integer value
						uiEPPI_FS1_PASPL	 |  EPPI FS1 Period							| 32 bit unsigned integer value
						uiEPPI_FS2_WLVB		 |  EPPI FS2 Width							| 32 bit unsigned integer value
						uiEPPI_FS2_PALPF	 |  EPPI FS2 Period							| 32 bit unsigned integer value

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_FSync_Config(unsigned int uiPID, unsigned int uiEPPI_FS1_WLHB , unsigned int uiEPPI_FS1_PASPL, unsigned int uiEPPI_FS2_WLVB , unsigned int uiEPPI_FS2_PALPF )
{
	switch(uiPID)
	{
		//EPPI0
		case 0:
			*pREG_EPPI0_FS1_WLHB 	= uiEPPI_FS1_WLHB;
			*pREG_EPPI0_FS1_PASPL	= uiEPPI_FS1_PASPL;
			*pREG_EPPI0_FS2_WLVB 	= uiEPPI_FS2_WLVB;
			*pREG_EPPI0_FS2_PALPF	= uiEPPI_FS2_PALPF;
			break;

		//EPPI1
		case 1:
	/*		*pREG_EPPI1_FS1_WLHB 	= uiEPPI_FS1_WLHB;
			*pREG_EPPI1_FS1_PASPL	= uiEPPI_FS1_PASPL;
			*pREG_EPPI1_FS2_WLVB 	= uiEPPI_FS2_WLVB;
			*pREG_EPPI1_FS2_PALPF	= uiEPPI_FS2_PALPF;*/
			break;

		//EPPI2
		case 2:
	/*		*pREG_EPPI2_FS1_WLHB 	= uiEPPI_FS1_WLHB;
			*pREG_EPPI2_FS1_PASPL	= uiEPPI_FS1_PASPL;
			*pREG_EPPI2_FS2_WLVB 	= uiEPPI_FS2_WLVB;
			*pREG_EPPI2_FS2_PALPF	= uiEPPI_FS2_PALPF;*/
			break;
	}
}


/**************************************************************************************************************************
	Function name	:   EPPI_Line_Config
    Description		:   This function initializes the value of EPPI Line, HCNT and HDelay registers
	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |   Peripheral ID (EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiEPPI_LINE		 	 |  EPPI_LINE register value				| 32 bit unsigned integer value
						uiEPPI_HCNT		 	 |  EPPI_HCNT register value	      	    | 32 bit unsigned integer value
						uiEPPI_HDLY		 	 |  EPPI_HDLY register value				| 32 bit unsigned integer value

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_Line_Config(unsigned int uiPID, unsigned int uiEPPI_LINE  , unsigned int uiEPPI_HCNT, unsigned int uiEPPI_HDLY)
{
	switch(uiPID)
	{
		//EPPI0
		case 0:
			*pREG_EPPI0_LINE 	= uiEPPI_LINE;
			*pREG_EPPI0_HCNT 	= uiEPPI_HCNT;
			*pREG_EPPI0_HDLY  	= uiEPPI_HDLY;
			break;

		//EPPI1
		case 1:
		/*	*pREG_EPPI1_LINE 	= uiEPPI_LINE;
			*pREG_EPPI1_HCNT 	= uiEPPI_HCNT;
			*pREG_EPPI1_HDLY  	= uiEPPI_HDLY;*/
			break;

		//EPPI2
		case 2:
		/*	*pREG_EPPI2_LINE 	= uiEPPI_LINE;
			*pREG_EPPI2_HCNT 	= uiEPPI_HCNT;
			*pREG_EPPI2_HDLY  	= uiEPPI_HDLY;*/
			break;
	}

}


/**************************************************************************************************************************
	Function name	:   EPPI_Frame_Config
    Description		:   This function initializes the value of EPPI Frame, VCNT and VDelay registers
	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |   Peripheral ID (EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiEPPI_FRAME		 |  EPPI_FRAME register value				| 32 bit unsigned integer value
						uiEPPI_VCNT		 	 |  EPPI_VCNT register value	      	    | 32 bit unsigned integer value
						uiEPPI_VDLY		 	 |  EPPI_VDLY register value				| 32 bit unsigned integer value

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_Frame_Config(unsigned int uiPID, unsigned int uiEPPI_FRAME, unsigned int uiEPPI_VCNT, unsigned int uiEPPI_VDLY)
{
	switch(uiPID)
	{
		//EPPI0
		case 0:
			*pREG_EPPI0_FRAME 	= uiEPPI_FRAME;
			*pREG_EPPI0_VCNT 	= uiEPPI_VCNT;
			*pREG_EPPI0_VDLY  	= uiEPPI_VDLY;
			break;

		//EPPI1
		case 1:
	/*		*pREG_EPPI1_FRAME 	= uiEPPI_FRAME;
			*pREG_EPPI1_VCNT 	= uiEPPI_VCNT;
			*pREG_EPPI1_VDLY  	= uiEPPI_VDLY;*/
			break;

		//EPPI2
		case 2:/*
			*pREG_EPPI2_FRAME 	= uiEPPI_FRAME;
			*pREG_EPPI2_VCNT 	= uiEPPI_VCNT;
			*pREG_EPPI2_VDLY  	= uiEPPI_VDLY;*/
			break;
	}

}


/**************************************************************************************************************************
	Function name	:   EPPI_IMASK_Config
    Description		:   This function initializes the value of EPPI IMASK register for enabling the interrupts.
	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |   Peripheral ID (EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiEPPI_IMSK		     |  EPPI_IMASK register value				| 32 bit unsigned integer value

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_IMASK_Config(unsigned int uiPID, unsigned int uiEPPI_IMSK )
{
	switch(uiPID)
	{
		//EPPI0
		case 0:
			*pREG_EPPI0_IMSK   = uiEPPI_IMSK;
			break;

		//EPPI1
		case 1:
	//		*pREG_EPPI1_IMSK   = uiEPPI_IMSK;
			break;

		//EPPI2
		case 2:
	//		*pREG_EPPI2_IMSK   = uiEPPI_IMSK;
			break;
	}

}


/**************************************************************************************************************************
	Function name	:   EPPI_Clip_Config
    Description		:   This function initializes the value of EPPI Even and Odd clipping registers.
	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |   Peripheral ID (EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiEPPI_ODDCLIP	     |  EPPI_ODDCLIP register value				| 32 bit unsigned integer value
						uiEPPI_EVENCLIP		 |  EPPI_EVENCLIP register value	      	    | 32 bit unsigned integer value

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_Clip_Config(unsigned int uiPID, unsigned int uiEPPI_ODDCLIP, unsigned int uiEPPI_EVENCLIP)
{
	switch(uiPID)
	{
		//EPPI0
		case 0:
			*pREG_EPPI0_ODDCLIP  	= uiEPPI_ODDCLIP;
			*pREG_EPPI0_EVENCLIP 	= uiEPPI_EVENCLIP;
			break;

		//EPPI1
		case 1:
	//		*pREG_EPPI1_ODDCLIP  	= uiEPPI_ODDCLIP;
	//		*pREG_EPPI1_EVENCLIP 	= uiEPPI_EVENCLIP;
			break;

		//EPPI2
		case 2:
	//		*pREG_EPPI2_ODDCLIP  	= uiEPPI_ODDCLIP;
	//		*pREG_EPPI2_EVENCLIP 	= uiEPPI_EVENCLIP;
			break;
	}

}


/**************************************************************************************************************************
	Function name	:   EPPI_Enable
    Description		:   This function Enables the EPPI module.

	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |  Peripheral ID (EPPI0, EPPI1, EPPI2..)	| 0,1,2

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_Enable(unsigned int uiPID)
{
	switch(uiPID)
	{
		//EPPI0
		case 0:

			*pREG_EPPI0_CTL |= ENUM_EPPI_CTL_EN ;           		 				// Enable EPPI0 module
			break;

		//EPPI1
		case 1:

		//	*pREG_EPPI1_CTL |= ENUM_EPPI_CTL_EN ;           		 				// Enable EPPI1 module
			break;

		//EPPI2
		case 2:

		//	*pREG_EPPI2_CTL |= ENUM_EPPI_CTL_EN ;           		 				// Enable EPPI2 module
			break;

	}

}



/**************************************************************************************************************************
	Function name	:   EPPI_DMANormal_Config
    Description		:   This function initializes the DMA channel for corresponding EPPI.
	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |  Peripheral ID (EPPI0, EPPI1, EPPI2..)	| 0,1,2
						iBufferAddress		 |  buffer start address 					| 32 bit  integer value
						iXModifier			 |  X modifier								| 32 bit  integer value
						uiXSize				 |  X count									| 32 bit  unsigned integer value
						iXModifier			 |  Y modifier								| 32 bit  integer value
						uiXSize				 |  Y count									| 32 bit  unsigned integer value
						uiDMAConfig			 |  DMA configuration register				| 32 bit  unsigned integer value

	Return value	:   None.
**************************************************************************************************************************/
void EPPI_DMANormal_Config(unsigned int uiPID, int* iBufferAddress, int iXModifier, unsigned int uiXSize, int iYModifier, unsigned int uiYSize, unsigned int uiDMAConfig)
{
	switch(uiPID)
	{
		//EPPI0  Y-DMA
		case 0:
			*pREG_DMA14_ADDRSTART = iBufferAddress;		//Initialize start address
			*pREG_DMA14_XCNT      = uiXSize;			//Initialize X count
			*pREG_DMA14_XMOD	  = iXModifier;			//Initialize DMA X modifier
			*pREG_DMA14_YCNT	  = uiYSize;			//Initialize Y count
			*pREG_DMA14_YMOD	  = iYModifier;			//Initialize DMA Y modifier
			*pREG_DMA14_CFG       = uiDMAConfig;		//Initialize DMA config register
			break;

		//EPPI1 Y-DMA
		case 1:
		/*	*pREG_DMA33_ADDRSTART = iBufferAddress;		//Initialize start address
			*pREG_DMA33_XCNT      = uiXSize;			//Initialize X count
			*pREG_DMA33_XMOD	  = iXModifier;			//Initialize DMA X modifier
			*pREG_DMA33_YCNT	  = uiYSize;			//Initialize Y count
			*pREG_DMA33_YMOD	  = iYModifier;			//Initialize DMA Y modifier
			*pREG_DMA33_CFG       = uiDMAConfig;		//Initialize DMA config register*/
			break;

		//EPPI2 Y-DMA
		case 2:/*
			*pREG_DMA31_ADDRSTART = iBufferAddress;		//Initialize start address
			*pREG_DMA31_XCNT      = uiXSize;			//Initialize X count
			*pREG_DMA31_XMOD	  = iXModifier;			//Initialize DMA X modifier
			*pREG_DMA31_YCNT	  = uiYSize;			//Initialize Y count
			*pREG_DMA31_YMOD	  = iYModifier;			//Initialize DMA Y modifier
			*pREG_DMA31_CFG       = uiDMAConfig;		//Initialize DMA config register*/
			break;
	}

}





/**************************************************************************************************************************
	Function name	:   EPPI_Pin_Config
    Description		:   This function initializes the Pin Muxing and FER register to enable EPPI pins.

	Arguments		:	Parameter			 |	Description		 						| Valid values
						uiPID				 |  Peripheral ID (EPPI0, EPPI1, EPPI2..)	| 0,1,2
						uiFS_MODE			 |  FrameSync mode							| 0,1,2,3
						uiDATAWIDTH			 |  PPI data width 							| 8,10,12,14,16,18,20(only for PPI0),
																						  24(only for PPI0)


	Return value	:   None.
**************************************************************************************************************************/

#endif /* __STRESS_TEST1_CORE0_H__ */
